==> shuup-2.3.16-py2.py3-none-any.whl: shuup/campaigns/admin_module/forms/__init__.py <==
# This file is part of Shuup.
#
# Copyright (c) 2012-2021, Shoop Commerce Ltd. All rights reserved.
#
# This source code is licensed under the OSL-3.0 license found in the
# LICENSE file in the root directory of this source tree.
from ._basket import BasketCampaignForm
from ._basket_conditions import (
    BasketMaxTotalAmountConditionForm,
    BasketMaxTotalProductAmountConditionForm, BasketTotalAmountConditionForm,
    BasketTotalProductAmountConditionForm,
    BasketTotalUndiscountedProductAmountConditionForm,
    CategoryProductsBasketConditionForm, ChildrenProductConditionForm,
    ContactBasketConditionForm, ContactGroupBasketConditionForm,
    HourBasketConditionForm, ProductsInBasketConditionForm
)
from ._basket_effects import (
    BasketDiscountAmountForm, BasketDiscountPercentageForm,
    DiscountFromCategoryProductsForm, DiscountFromProductForm,
    DiscountPercentageFromUndiscountedForm, FreeProductLineForm
)
from ._catalog import CatalogCampaignForm
from ._catalog_conditions import (
    ContactConditionForm, ContactGroupConditionForm, HourConditionForm
)
from ._catalog_effects import (
    ProductDiscountAmountForm, ProductDiscountPercentageForm
)
from ._catalog_filters import (
    CategoryFilterForm, ProductFilterForm, ProductTypeFilterForm
)
from ._coupon import CouponForm

__all__ = [
    "BasketCampaignForm",
    "BasketDiscountAmountForm",
    "BasketDiscountPercentageForm",
    "BasketMaxTotalAmountConditionForm",
    "BasketMaxTotalProductAmountConditionForm",
    "BasketTotalAmountConditionForm",
    "BasketTotalProductAmountConditionForm",
    "BasketTotalUndiscountedProductAmountConditionForm",
    "CatalogCampaignForm",
    "CategoryFilterForm",
    "CategoryProductsBasketConditionForm",
    "ContactBasketConditionForm",
    "ContactConditionForm",
    "HourConditionForm",
    "HourBasketConditionForm",
    "ContactGroupBasketConditionForm",
    "ContactGroupConditionForm",
    "CouponForm",
    "DiscountFromCategoryProductsForm",
    "DiscountFromProductForm",
    "DiscountPercentageFromUndiscountedForm",
    "FreeProductLineForm",
    "ProductDiscountAmountForm",
    "ProductDiscountPercentageForm",
    "ProductFilterForm",
    "ProductsInBasketConditionForm",
    "ProductTypeFilterForm",
    "ChildrenProductConditionForm"
]

==> shuup-2.13.0-py2.py3-none-any.whl: shuup/campaigns/admin_module/forms/__init__.py <==
# This file is part of Shuup.
#
# Copyright (c) 2012-2021, Shuup Commerce Inc. All rights reserved.
#
# This source code is licensed under the OSL-3.0 license found in the
# LICENSE file in the root directory of this source tree.
from ._basket import BasketCampaignForm
from ._basket_conditions import (
    BasketMaxTotalAmountConditionForm,
    BasketMaxTotalProductAmountConditionForm,
    BasketTotalAmountConditionForm,
    BasketTotalProductAmountConditionForm,
    BasketTotalUndiscountedProductAmountConditionForm,
    CategoryProductsBasketConditionForm,
    ChildrenProductConditionForm,
    ContactBasketConditionForm,
    ContactGroupBasketConditionForm,
    HourBasketConditionForm,
    ProductsInBasketConditionForm,
)
from ._basket_effects import (
    BasketDiscountAmountForm,
    BasketDiscountPercentageForm,
    DiscountFromCategoryProductsForm,
    DiscountFromProductForm,
    DiscountPercentageFromUndiscountedForm,
    FreeProductLineForm,
)
from ._catalog import CatalogCampaignForm
from ._catalog_conditions import ContactConditionForm, ContactGroupConditionForm, HourConditionForm
from ._catalog_effects import ProductDiscountAmountForm, ProductDiscountPercentageForm
from ._catalog_filters import CategoryFilterForm, ProductFilterForm, ProductTypeFilterForm
from ._coupon import CouponForm

__all__ = [
    "BasketCampaignForm",
    "BasketDiscountAmountForm",
    "BasketDiscountPercentageForm",
    "BasketMaxTotalAmountConditionForm",
    "BasketMaxTotalProductAmountConditionForm",
    "BasketTotalAmountConditionForm",
    "BasketTotalProductAmountConditionForm",
    "BasketTotalUndiscountedProductAmountConditionForm",
    "CatalogCampaignForm",
    "CategoryFilterForm",
    "CategoryProductsBasketConditionForm",
    "ContactBasketConditionForm",
    "ContactConditionForm",
    "HourConditionForm",
    "HourBasketConditionForm",
    "ContactGroupBasketConditionForm",
    "ContactGroupConditionForm",
    "CouponForm",
    "DiscountFromCategoryProductsForm",
    "DiscountFromProductForm",
    "DiscountPercentageFromUndiscountedForm",
    "FreeProductLineForm",
    "ProductDiscountAmountForm",
    "ProductDiscountPercentageForm",
    "ProductFilterForm",
    "ProductsInBasketConditionForm",
    "ProductTypeFilterForm",
    "ChildrenProductConditionForm",
]
